@@ -1511,6 +1511,7 @@ public:
     void updateWindowShadow(bool isForceUpdate = false);
     DecorationStyle  *windowStyleObj() const;
     void createWinStyle();
+    void updateWinProperty();
 
     void setStartUpEffectType(int type) { m_startEffectType = type; }
     int startUpEffectType() { return m_startEffectType; }
@@ -1527,6 +1528,7 @@ public:
     QVariant createTimespanDBusMessage(struct timeval createTimeval, int tid, std::string event);
 
     GLTexture *getPreviousTexture();
+    void updateFrameGeometry(QRectF rect);
 
     QMargins extendResizeBorder() const;
 
@@ -2040,6 +2042,7 @@ protected:
     bool m_isShapeBoundingRegionSet = false;
     int  m_startEffectType = 1;
     bool m_isScissorForce = false;
+    bool m_isMouseInputAreaMarginsAvailable = true;
 
 private Q_SLOTS:
     void shadeHover();
